"""Top-level package for cloup."""

__author__ = """Gianluca Gippetto"""
__email__ = 'gianluca.gippetto@gmail.com'
__version__ = '0.1.0'

from ._cloup import (
    OptionGroup,
    GroupedOption,
    CloupGroup,
    CloupCommand,
    option_group,
    option,
    command,
    group
)
